# Awesome-Monaco
#### little studing project for FoxmindED



###### usage:
> start.py [-h] --files FILES (--asc | --desc | --driver DRIVER)


###### options:

> -h, --help show this help message and exit
> 
> --files FILES    Enter your folder path
>
>--asc            direct order
>--desc           undirected order
> 
>--driver DRIVER  driver name
